#[non_exhaustive]pub enum Error {
ChannelError {
context: String,
},
IdGeneration(Infallible),
RequestCancelled,
InvalidRequest {
reason: String,
},
ServiceShutdown,
}Expand description
Unified error type for the ID generation service.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ChannelError
Internal channel send/receive failure (e.g., closed or full channel).
IdGeneration(Infallible)
Underlying Snowflake ID generation failed. This is currently infallible, but kept as a placeholder if the generator type yields an error.
RequestCancelled
The client aborted the request.
InvalidRequest
The client request was invalid or exceeded constraints.
ServiceShutdown
The service is in the process of shutting down.